credentials
===========

.. NOTE::
   The following class is not intended for use by those using Pika in their applications. This documentation is for those who are extending Pika or otherwise working on the driver itself.

.. automodule:: credentials

PlainCredentials
----------------
.. autoclass:: PlainCredentials
   :members:
   :inherited-members:
   :noindex:

